using System;
using System.Collections;
using Server.Items;

namespace Server.Spells.FSB
{
    [Flags]
    /********************************\Instructions/********************************/
    /*                              Add New Schools                               */
    /*      To be able to turn schools on/off in game, you must add a flag and a  */
    /*      bool variable here for each school.                                   */
    /******************************************************************************/
    /*      SchoolFlags increment with this pattern :                             */
    /*      0, 1, 2, 4, 8, 10, 20, 40, 80, 100, 200, 400, 800.                    */
    /*      Preceded by the 0x000...                                              */
    /*      Just have them match up with the prior ones.                          */
    /******************************************************************************/
    public enum SchoolFlag
    {
		None        =   0x00000000,
		Magery      =   0x00000001,
		Necro       =   0x00000002,
		Chivalry    =   0x00000004,
		Ninja       =   0x00000008,
		Samurai     =   0x00000010,
		Rogue       =   0x00000020,
		Ancient     =   0x00000040,
		Druid       =   0x00000080,
		Cleric      =   0x00000100,
		Bard        =   0x00000200,
		Ranger      =   0x00000400,

        /*  Example
        NAMEOFFLAG  =   0x00000400,
        End Example*/
    }

    [PropertyObject]
    public class FSBSchoolFlags
    {
		private TomeOfKnowledge m_Book;

        [CommandProperty( AccessLevel.GameMaster )]
        public bool _01_Magery{ get{ return m_Book.GetFlag( SchoolFlag.Magery ); } set{ m_Book.SetFlag( SchoolFlag.Magery, value ); } }

        [CommandProperty( AccessLevel.GameMaster )]
        public bool _02_Necromancy{ get{ return m_Book.GetFlag( SchoolFlag.Necro ); } set{ m_Book.SetFlag( SchoolFlag.Necro, value ); } }

        [CommandProperty( AccessLevel.GameMaster )]
        public bool _03_Chivalry{ get{ return m_Book.GetFlag( SchoolFlag.Chivalry ); } set{ m_Book.SetFlag( SchoolFlag.Chivalry, value ); } }

        [CommandProperty( AccessLevel.GameMaster )]
        public bool _04_Bushido{ get{ return m_Book.GetFlag( SchoolFlag.Samurai ); } set{ m_Book.SetFlag( SchoolFlag.Samurai, value ); } }

        [CommandProperty( AccessLevel.GameMaster )]
        public bool _05_Ninjitsu{ get{ return m_Book.GetFlag( SchoolFlag.Ninja ); } set{ m_Book.SetFlag( SchoolFlag.Ninja, value ); } }

        [CommandProperty( AccessLevel.GameMaster )]
        public bool _06_Rogue{ get{ return m_Book.GetFlag( SchoolFlag.Rogue ); } set{ m_Book.SetFlag( SchoolFlag.Rogue, value ); } }

        [CommandProperty( AccessLevel.GameMaster )]
        public bool _07_Ancient{ get{ return m_Book.GetFlag( SchoolFlag.Ancient ); } set{ m_Book.SetFlag( SchoolFlag.Ancient, value ); } }

        [CommandProperty( AccessLevel.GameMaster )]
        public bool _08_Druid{ get{ return m_Book.GetFlag( SchoolFlag.Druid ); } set{ m_Book.SetFlag( SchoolFlag.Druid, value ); } }

        [CommandProperty( AccessLevel.GameMaster )]
        public bool _09_Cleric{ get{ return m_Book.GetFlag( SchoolFlag.Cleric ); } set{ m_Book.SetFlag( SchoolFlag.Cleric, value ); } }

        [CommandProperty( AccessLevel.GameMaster )]
        public bool _10_Bard{ get{ return m_Book.GetFlag( SchoolFlag.Bard ); } set{ m_Book.SetFlag( SchoolFlag.Bard, value ); } }

        [CommandProperty( AccessLevel.GameMaster )]
        public bool _11_Ranger{ get{ return m_Book.GetFlag( SchoolFlag.Ranger ); } set{ m_Book.SetFlag( SchoolFlag.Ranger, value ); } }

        /******************************************************************************/
        /*                              Add New Schools                               */
        /*                         Example of bool variable                           */
        /******************************************************************************
        [CommandProperty( AccessLevel.GameMaster )]
        public bool NAMEOFFLAG{ get{ return GetFlag( SchoolFlag.NAMEOFFLAG ); } set{ SetFlag( SchoolFlag.NAMEOFFLAG, value ); } }
        /******************************************************************************/
        /*                              End of Example                                */
        /******************************************************************************/

		// Add new Reagents that the book can hold here.
		public static Type[] m_RegTypes = new Type[]
		{
			typeof( BlackPearl ),
			typeof( Bloodmoss ),
			typeof( Garlic ),
			typeof( Ginseng ),
			typeof( MandrakeRoot ),
			typeof( Nightshade ),
			typeof( SulfurousAsh ),
			typeof( SpidersSilk ),
			typeof( BatWing ),
			typeof( GraveDust ),
			typeof( DaemonBlood ),
			typeof( NoxCrystal ),
			typeof( PigIron ),
			typeof( PetrafiedWood ),
			typeof( DestroyingAngel ),
			typeof( SpringWater ),
			typeof( Kindling ),
		};

        public FSBSchoolFlags( TomeOfKnowledge book )
        {
			m_Book = book;
		}

		public override string ToString()
		{
			return "...";
		}
	}
}