using System;
using Server;
using Server.Gumps;
using Server.Network;
using System.Collections;


namespace Server.Spells.FSB
{
    public class TomeOfKnowledgeGump : Gump
    {
        public Mobile m_From;
        public TomeOfKnowledge m_Book;
        public FSBBaseSkin Skin;
        public FSBBaseOptionSkin OptionSkin;

        public TomeOfKnowledgeGump( Mobile from, TomeOfKnowledge book ) : base( book.StartX, book.StartY )
        {
            m_From = from;
            m_Book = book;

            Closable = m_Book.GetFlag( BookFlag.Closable );
            Disposable=true;
            Dragable=false;
            Resizable=false;

			m_From.CloseGump( typeof( ReagentsGump ) );
			if( m_Book.GetFlag( BookFlag.KeepRegs ) && m_Book.GetFlag( BookFlag.ShowRegs ) && m_Book.Refresher != null && !m_Book.Refresher.Running )
				m_Book.Refresher.Start();
			else if( m_Book.GetFlag( BookFlag.ShowRegs ) && !m_Book.GetFlag( BookFlag.KeepRegs ) )
				from.SendGump( new ReagentsGump( m_From, m_Book, false ) );

            AddPage(0);

            Skin = FSBSkinList.GetSkin( m_Book.Skin );
            OptionSkin = FSBSkinList.GetOptionSkin( m_Book.Skin );

			Skin.CreateGump( m_Book, this );
        }

        public override void OnResponse( NetState state, RelayInfo info )
        {
			if( m_Book.Deleted )
				return;

			Mobile from = state.Mobile;
			int BID = info.ButtonID;
			//Exit
			if( BID == 0 )
			{
				from.CloseGump( typeof( TomeOfKnowledgeGump ) );
			}//Exit

			//Options
			else if( BID == 1 )
			{
				if( m_Book.CurrentSchool == (FSBSchoolInfo)FSBSchoolList.SchoolList[1] )
					m_Book.CurrentSchool = (FSBSchoolInfo)FSBSchoolList.SchoolList[0];
				else
					m_Book.CurrentSchool = (FSBSchoolInfo)FSBSchoolList.SchoolList[1];
				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Options

			//Options Apply
			else if( BID == 5 )
			{
				m_Book.SetFlag( BookFlag.Closable, info.IsSwitched( 2 ) );
				m_Book.SetFlag( BookFlag.ShowRegs, info.IsSwitched( 11 ) );
				if( !info.IsSwitched( 11 ) )
				{
					m_Book.SetFlag( BookFlag.KeepRegs, false );
					if( m_Book.Refresher != null )
						m_Book.Refresher.Stop();
					from.CloseGump( typeof( ReagentsGump ) );
				}

				TextRelay xrelay = info.GetTextEntry( 3 );
				TextRelay yrelay = info.GetTextEntry( 4 );
				string xtext = ( xrelay == null ? null : xrelay.Text.Trim() );
				string ytext = ( yrelay == null ? null : yrelay.Text.Trim() );

				if( xtext == null || xtext.Length == 0 || ytext == null || ytext.Length == 0 )
				{
					from.SendMessage("You must enter a positive integer value in the box. (0 , 400, 245 )");
				}
				else
				{
					int x = 5; //m_Book.StartX;
					int y = 75; //m_Book.StartY;
					try
					{
						x = Int32.Parse(xtext);
						y = Int32.Parse(ytext);

						if( x >= 0 && y >= 0  )
						{
							m_Book.StartX = x;
							m_Book.StartY = y;
							m_Book.PublicOverheadMessage( MessageType.Whisper, 0, false, "Updated X Coordinate to : " + xtext );
							m_Book.PublicOverheadMessage( MessageType.Whisper, 0, false, "Updated Y Coordinate to : " + ytext );
						}
						else
							from.SendMessage("You must enter a positive integer value in both boxes. (0 , 400, 245 )");
					}
					catch
					{
						from.SendMessage("You must enter a positive integer value in both boxes. (0 , 400, 245 )");
					}
				}
				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Options Apply

			//Remove Icons
			else if( BID == 6 )
			{
				m_Book.DragableIcons.Clear();
				from.SendMessage( "All Icons have been deleted" );
				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Remove Icons

			//Remove Keywords
			else if( BID == 7 )
			{
				m_Book.Keywords.Clear();
				from.SendMessage( "All Keywords have been deleted" );
				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Remove Keywords

			//Update Keywords
			else if( BID == 8 )
			{
				for( int i = 0; i < OptionSkin.KeywordsPerPage; i++ )
				{
					int Index = (i + m_Book.OptionsOffset - OptionSkin.KeywordsPerPage);
					if( Index >= m_Book.Keywords.Count || Index < 0 )
						continue;

					TextRelay keywordRelay = info.GetTextEntry( 200+i );
					string keyword = ( keywordRelay == null ? null : keywordRelay.Text.Trim() );
					if( keyword == null || keyword.Length == 0 )
					{
						from.SendMessage( "Removing keyword" );
						FSBKeyword kw = new FSBKeyword( -1, "" );
						m_Book.Keywords.RemoveAt( Index );
						m_Book.Keywords.Insert( Index, kw );
					}
					else
					{
						from.SendMessage( "Changing keyword" );
						FSBKeyword kw = new FSBKeyword( ((FSBKeyword)m_Book.Keywords[Index]).Spell, keyword );
						m_Book.Keywords.RemoveAt( Index );
						m_Book.Keywords.Insert( Index, kw );
					}
				}

				ArrayList Temp = new ArrayList();
				for( int i = 0; i < m_Book.Keywords.Count; i++ )
				{
					FSBKeyword kw = m_Book.Keywords[i] as FSBKeyword;
					if( kw.Spell != -1 )
						Temp.Add( kw );
				}

				m_Book.Keywords.Clear();
				for( int i = 0; i < Temp.Count; i++ )
					m_Book.Keywords.Add( (FSBKeyword)Temp[i] );

				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Update Keywords

			//Keywords Previous
			else if( BID == 9 )
			{
				m_Book.OptionsOffset -= OptionSkin.KeywordsPerPage;
				if( m_Book.OptionsOffset < OptionSkin.KeywordsPerPage )
					m_Book.OptionsOffset = OptionSkin.KeywordsPerPage;
				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Keywords Previous

			//Keywords Next
			else if( BID == 10 )
			{
				m_Book.OptionsOffset += OptionSkin.KeywordsPerPage;
				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Keywords Next

			//Spells Prev
			else if( BID == 12 )
			{
				m_Book.SpellsOffset -= Skin.SpellsPerPage;
				if( m_Book.SpellsOffset < Skin.SpellsPerPage )
					m_Book.SpellsOffset = Skin.SpellsPerPage;
				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Spells Prev

			//Spells Next
			else if( BID == 13 )
			{
				m_Book.SpellsOffset += Skin.SpellsPerPage;
				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Spells Next

			//Info Apply Keyword
			else if( BID == 15 )
			{
				TextRelay keywordRelay = info.GetTextEntry( 14 );
				string keyword = ( keywordRelay == null ? null : keywordRelay.Text.Trim() );

				m_Book.AddKeyword( keyword, m_Book.CurrentSpell );

				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Info Apply Keyword

			//Skin Change
			else if( BID == 16 )
			{
				if( m_Book.Skin + 1 > FSBSkinList.HighestSkin )
					m_Book.Skin = 0;
				else
					m_Book.Skin++;

				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Skin Change

			//Spell Casts
			else if( BID >= 1000 && BID < 2000 )
			{
				Spell spell = SpellRegistry.NewSpell( BID - 1000, from, null );
				if( spell != null )
					spell.Cast();

				from.CloseGump( typeof( ReagentsGump ) );
				new GumpUpTimer( m_From, m_Book );
			}//Spell Casts

			//Spell Infos
			else if( BID >= 2000 && BID < 3000 )
			{
				if( BID - 2000 == m_Book.CurrentSpell )
					m_Book.CurrentSpell = -1;
				else
					m_Book.CurrentSpell = BID - 2000;

				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//Spell Infos

			//Spell Icons
			else if( BID >= 3000 && BID < 4000 )
			{
				FSBSpellInfo si = FSBSpellList.FindSpellInfo( BID - 3000 );
				if( si == null )
					return;

				int background = FSBSchoolList.FindBackgroundInfo( si.School );
				if( background == -1 )
					return;

				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
				from.SendGump( new IconPlacementGump( m_Book, from, 375, 115, 5, si.SpellIcon, si.SpellReg, background ) );
			}//Spell Icons

			//School Selects
			else if( BID >= 100 && BID < 200 )
			{
				if( m_Book.CurrentSchool == (FSBSchoolInfo)FSBSchoolList.SchoolList[BID-100] )
					m_Book.CurrentSchool = (FSBSchoolInfo)FSBSchoolList.SchoolList[0];
				else
					m_Book.CurrentSchool = (FSBSchoolInfo)FSBSchoolList.SchoolList[BID-100];

				from.SendGump( new TomeOfKnowledgeGump( from, m_Book ) );
			}//School Selects

			else
			{
				from.SendMessage( string.Format( "Button #{0} pressed", BID ) );
			}
		}

		private class GumpUpTimer : Timer
		{
			Mobile m_From;
			TomeOfKnowledge m_Book;
			public GumpUpTimer( Mobile from, TomeOfKnowledge book ) : base( TimeSpan.FromSeconds(5) )
			{
				m_From = from;
				m_Book = book;
				this.Start();
			}

			protected override void OnTick()
			{
				m_From.SendGump( new TomeOfKnowledgeGump( m_From, m_Book ) );
				if( m_Book.GetFlag( BookFlag.ShowRegs ) && !m_Book.GetFlag( BookFlag.KeepRegs ) )
					m_From.SendGump( new ReagentsGump( m_From, m_Book, false ) );
				this.Stop();
			}
		}
    }
}
