using System;
using Server.Items;
using Server.LucidNagual;
using Server.Mobiles;
using Server.ACC.CM;
using Server.Enums;


namespace Server.Spells.FSB
{
	public class FSBSettings
	{
		internal static Mobile from;
		
		// Set this to true if you want to enable schools
		// by dropping that type of Spellbook onto the ToK.
		public static bool EnableOnDrop = true;
		
		// Set this to true if you want to allow the player
		// to drop more than one of the same type of Spellbook.
		// Ex.: 2 Magery Spellbooks
		public static bool ReDrop = false;
		
		// Set this to true if you plan on giving this book
		// out with a Class-Specific Enabled list.
		// Ex.: Mage gets Magery enabled, Ranger gets cleric/druid enabled, etc.
		public static bool ClassEnabled = true;
		
		// This method is called when a ToK is created.
		// You can set which schools are enabled by default.
		// If EnableOnDrop, it will return, leaving all
		// schools off until they add that spellbook.
		// Change that if you want :)
		// A list of all the Flags can be found in Lists\FSBSchoolFlags.cs
		public static void InitSchools( TomeOfKnowledge tok )
		{
			PlayerMobile player = from as PlayerMobile;
			
			if( EnableOnDrop )
				return;
			
			if( ClassEnabled )
				return;
			
			if( player.AccessLevel == AccessLevel.Administrator )
				tok.SetFlag( SchoolFlag.Ancient, true );
			
			tok.SetFlag( SchoolFlag.Magery, true );
			tok.SetFlag( SchoolFlag.Necro, true );
			tok.SetFlag( SchoolFlag.Chivalry, true );
			tok.SetFlag( SchoolFlag.Rogue, true );
			tok.SetFlag( SchoolFlag.Druid, true );
			tok.SetFlag( SchoolFlag.Cleric, true );
			tok.SetFlag( SchoolFlag.Bard, true );
			tok.SetFlag( SchoolFlag.Ranger, true );
			tok.SetFlag( SchoolFlag.Chivalry, true );
			tok.SetFlag( SchoolFlag.Ninja, true );
			tok.SetFlag( SchoolFlag.Samurai, true );
			//tok.SetFlag( SchoolFlag.Arcanist, true );
		}
		
		// This method is called when an unowned book is double clicked on for the first time.
		// You can set up some restrictions here.  You can test 'from's skills or titles, etc
		// and set the SchoolFlags to what you want accordingly.
		public static void InitRestrictions( TomeOfKnowledge tok, Mobile from )
		{
			PlayerMobile pm = from as PlayerMobile;
			PlayerModule mod = pm.PlayerModule;

			if ( !DataCenter.EnableClassSystem )
				return;
			
			//if( EnableOnDrop )
			//	return;
			
			if( from.AccessLevel > AccessLevel.Player )
				return;
			
			if (  mod != null && from != null && tok != null )
			{
				if( from.AccessLevel == AccessLevel.Administrator ) //Set your staff accesslevel here.
					tok.SetFlag( SchoolFlag.Ancient, true );        //For ancient spells.
				
				else if ( mod.PlayerClasses == PlayerClasses.None )
					return;
				
				else if ( mod.PlayerClasses == PlayerClasses.Nomad )
					return;
				
				else if ( mod.PlayerClasses == PlayerClasses.Mage )
					tok.SetFlag( SchoolFlag.Magery, true );
				
				else if ( mod.PlayerClasses == PlayerClasses.Paladin )
					tok.SetFlag( SchoolFlag.Chivalry, true );
				
				else if ( mod.PlayerClasses == PlayerClasses.Rogue )
					tok.SetFlag( SchoolFlag.Rogue, true );
				
				else if ( mod.PlayerClasses == PlayerClasses.Druid )
					tok.SetFlag( SchoolFlag.Druid, true );
				
				else if ( mod.PlayerClasses == PlayerClasses.Cleric )
					tok.SetFlag( SchoolFlag.Cleric, true );
				
				else if ( mod.PlayerClasses == PlayerClasses.Bard )
					tok.SetFlag( SchoolFlag.Bard, true );
				
				else if ( mod.PlayerClasses == PlayerClasses.Paladin )
					tok.SetFlag( SchoolFlag.Avatar, true );
				
				else if ( mod.PlayerClasses == PlayerClasses.Ranger )
					tok.SetFlag( SchoolFlag.Ranger, true );
				
				else if ( mod.PlayerClasses == PlayerClasses.Tamer )
				{
					tok.SetFlag( SchoolFlag.Druid, true );
					tok.SetFlag( SchoolFlag.Bard, true );
				}
				
				else if ( mod.PlayerClasses == PlayerClasses.Necromancer )
				{
					tok.SetFlag( SchoolFlag.Necro, true );
					tok.SetFlag( SchoolFlag.Undead, true );
				}
				
				//For RunUO 2.0
				else if ( mod.PlayerClasses == PlayerClasses.Ninja )
					tok.SetFlag( SchoolFlag.Ninja, true );
				
				else if ( mod.PlayerClasses == PlayerClasses.Samurai )
					tok.SetFlag( SchoolFlag.Samurai, true );
				//For RunUO 2.0
				
				//For ML Edition.
				//else if ( mod.PlayerModule == PlayerModule.Arcanist )
				//	tok.SetFlag( SchoolFlag.Arcanist, true );
				//For ML Edition.
				
				else
					return;
				
				//if( from.Skills[SkillName.Magery].Value > 20 )
				//	tok.SetFlag( SchoolFlag.Magery, true );
			}
		}
	}
}
