using System;
using System.Collections;
using Server;
using Server.Targeting;
using Server.Network;
using Server.Mobiles;
using Server.Items;
using Server.Spells;
using Server.Spells.Seventh;
using Server.Gumps;


namespace Server.Spells.Rogue
{
	public class IntimidationSpell : Spell
	{
		private static SpellInfo m_Info = new SpellInfo(
		                                                "Intimidation", " ",
		                                                SpellCircle.Fourth,
		                                                212,
		                                                9041
		                                               );
		
		private static Hashtable m_Table = new Hashtable();
		
		public IntimidationSpell( Mobile caster, Item scroll ) : base( caster, scroll, m_Info )
		{
		}
		
		public static bool HasEffect( Mobile m )
		{
			return ( m_Table[m] != null );
		}
		
		public static void RemoveEffect( Mobile m )
		{
			object[] mods = (object[])m_Table[m];
			
			if ( mods != null )
			{
				m.RemoveStatMod( ((StatMod)mods[0]).Name );
				m.RemoveStatMod( ((StatMod)mods[1]).Name );
				m.RemoveSkillMod( (SkillMod)mods[2] );
				m.RemoveSkillMod( (SkillMod)mods[3] );
				m.RemoveSkillMod( (SkillMod)mods[4] );
				m.RemoveSkillMod( (SkillMod)mods[5] );
				m.RemoveSkillMod( (SkillMod)mods[6] );
			}
			
			m_Table.Remove( m );
			
			m.EndAction( typeof( IntimidationSpell ) );
			
			m.BodyMod = 0;
		}
		
		public override bool CheckCast()
		{
			if ( Server.Spells.AllSpells.CheckRestriction( Caster, 7 ) == false )
				return false;
			
			if ( !base.CheckCast() )
			{
				return false;
			}
			else if ( !Caster.CanBeginAction( typeof( IntimidationSpell ) ) )
			{
				Caster.SendLocalizedMessage( 1005559 );
				return false;
			}
			else if ( Necromancy.TransformationSpell.UnderTransformation( Caster ) )
			{
				Caster.SendMessage( "You cannot transform while in that form." );
				return false;
			}
			else if ( DisguiseGump.IsDisguised( Caster ) )
			{
				Caster.SendMessage( "You cannot transform while disguised." );
				return false;
			}
			else if ( Caster.BodyMod == 183 || Caster.BodyMod == 184 )
			{
				Caster.SendMessage( "You cannot transform while wearing body paint." );
				return false;
			}
			else if ( !Caster.CanBeginAction( typeof( PolymorphSpell ) ) )
			{
				Caster.SendMessage( "You cannot transform while polymorphed." );
				return false;
			}
			
			return true;
		}
		
		public override void OnCast()
		{
			if ( !Caster.CanBeginAction( typeof( IntimidationSpell ) ) )
			{
				IntimidationSpell.RemoveEffect( Caster );
			}
			else if ( Necromancy.TransformationSpell.UnderTransformation( Caster ) )
			{
				Caster.SendMessage( "You cannot transform while in that form." );
			}
			else if ( DisguiseGump.IsDisguised( Caster ) )
			{
				Caster.SendMessage( "You cannot transform while disguised." );
			}
			else if ( Caster.BodyMod == 183 || Caster.BodyMod == 184 )
			{
				Caster.SendMessage( "You cannot transform while wearing body paint." );
			}
			else if ( !Caster.CanBeginAction( typeof( PolymorphSpell ) ) )
			{
				Caster.SendMessage( "You cannot transform while polymorphed." );
			}
			else if ( CheckSequence() )
			{
				object[] mods = new object[]
				{
					new StatMod( StatType.Dex, "[Rogue] Dex Offset", -20, TimeSpan.Zero ),
					new StatMod( StatType.Str, "[Rogue] Str Offset", 20, TimeSpan.Zero ),
					new DefaultSkillMod( SkillName.Hiding, true, -20 ),
					new DefaultSkillMod( SkillName.Stealth, true, -20 ),
					new DefaultSkillMod( SkillName.Swords, true, 20 ),
					new DefaultSkillMod( SkillName.Macing, true, 20 ),
					new DefaultSkillMod( SkillName.Fencing, true, -20 )
						
				};
				
				m_Table[Caster] = mods;
				
				Caster.AddStatMod( (StatMod)mods[0] );
				Caster.AddStatMod( (StatMod)mods[1] );
				Caster.AddSkillMod( (SkillMod)mods[2] );
				Caster.AddSkillMod( (SkillMod)mods[3] );
				Caster.AddSkillMod( (SkillMod)mods[4] );
				Caster.AddSkillMod( (SkillMod)mods[5] );
				Caster.AddSkillMod( (SkillMod)mods[6] );
				
				new InternalTimer( Caster, TimeSpan.FromMinutes( 1 ) ).Start();
				
				IMount mount = Caster.Mount;
				
				if ( mount != null )
					mount.Rider = null;
				
				Caster.BeginAction( typeof( IntimidationSpell ) );
			}
		}
		
		
		private class InternalTimer : Timer
		{
			private Mobile m_Owner;
			private DateTime m_Expire;
			
			public InternalTimer( Mobile owner, TimeSpan duration ) : base( TimeSpan.Zero, TimeSpan.FromSeconds( 0.1 ) )
			{
				m_Owner = owner;
				m_Expire = DateTime.Now + duration;
				
			}
			
			protected override void OnTick()
			{
				if ( DateTime.Now >= m_Expire )
				{
					IntimidationSpell.RemoveEffect( m_Owner );
					Stop();
				}
			}
		}
	}
}
