using System;
using Server.Targeting;
using Server.Network;
using Server.Items;


namespace Server.Spells.Second
{
	public class DestroyTrapSpell : Spell
	{
		private static SpellInfo m_Info = new SpellInfo(
		                                                "Destroy Trap", "An Jux",
		                                                SpellCircle.Second,
		                                                212,
		                                                9001,
		                                                Reagent.Bloodmoss,
		                                                Reagent.SulfurousAsh
		                                               );
		
		public DestroyTrapSpell( Mobile caster, Item scroll ) : base( caster, scroll, m_Info )
		{
		}
		
		public override void OnCast()
		{
			if ( Server.Spells.AllSpells.CheckRestriction( Caster, 99 ) == false )
				return;
			
			Caster.Target = new InternalTarget( this );
			Caster.SendMessage( "Which trap do you wish to destroy?" );
		}
		
		public void Target( HouseTrap item )
		{
			if ( !Caster.CanSee( item ) )
			{
				Caster.SendLocalizedMessage( 500237 ); // Target can not be seen.
			}
			
			else if ( CheckSequence() )
			{
				SpellHelper.Turn( Caster, item );
				
				Point3D loc = item.GetWorldLocation();
				
				Blood shards = new Blood();
				shards.ItemID=0xC2D;
				shards.Map=item.Map;
				shards.Location=loc;
				Effects.PlaySound( loc, item.Map, 0x305 );
				if(item.Placer!=null)
					item.Placer.SendMessage("A trap you placed has been destroyed!");
				
				
				item.Delete();
				Caster.SendMessage("You destroy the trap!");
			}
			
			FinishSequence();
		}
		
		private class InternalTarget : Target
		{
			private DestroyTrapSpell m_Owner;
			
			public InternalTarget( DestroyTrapSpell owner ) : base( 12, false, TargetFlags.None )
			{
				m_Owner = owner;
			}
			
			protected override void OnTarget( Mobile from, object o )
			{
				if ( o is HouseTrap )
				{
					m_Owner.Target( (HouseTrap)o );
				}
				else
				{
					from.SendMessage( "You can't destroy that" );
				}
			}
			
			protected override void OnTargetFinish( Mobile from )
			{
				m_Owner.FinishSequence();
			}
		}
	}
}
