using System;
using System.Collections;
using Server.Network;
using Server.Items;
using Server.Targeting;


namespace Server.Spells.Seventh
{
	public class MassMightSpell : Spell
	{
		private static SpellInfo m_Info = new SpellInfo(
		                                                "Mass Might", "In Vas Por",
		                                                SpellCircle.Seventh,
		                                                215,
		                                                9061,
		                                                Reagent.BlackPearl,
		                                                Reagent.MandrakeRoot,
		                                                Reagent.Ginseng
		                                               );
		
		public MassMightSpell( Mobile caster, Item scroll ) : base( caster, scroll, m_Info )
		{
		}
		
		public override void OnCast()
		{
			if ( Server.Spells.AllSpells.CheckRestriction( Caster, 99 ) == false )
				return;
			
			Caster.Target = new InternalTarget( this );
		}
		
		public void Target( IPoint3D p )
		{
			if ( !Caster.CanSee( p ) )
			{
				Caster.SendLocalizedMessage( 500237 ); // Target can not be seen.
			}
			else if ( CheckSequence() )
			{
				if(this.Scroll!=null)
					Scroll.Consume();
				SpellHelper.Turn( Caster, p );
				
				SpellHelper.GetSurfaceTop( ref p );
				
				ArrayList targets = new ArrayList();
				
				Map map = Caster.Map;
				
				if ( map != null )
				{
					IPooledEnumerable eable = map.GetMobilesInRange( new Point3D( p ), 3 );
					
					foreach ( Mobile m in eable )
					{
						if ( Caster.CanBeBeneficial( m, false ) )
							targets.Add( m );
					}
					
					eable.Free();
				}
				
				Effects.PlaySound( p, Caster.Map, 0x299 );
				
				if ( targets.Count > 0 )
				{
					
					for ( int i = 0; i < targets.Count; ++i )
					{
						Mobile targ = (Mobile)targets[i];
						
						SpellHelper.AddStatBonus( Caster, targ, StatType.Str ); SpellHelper.DisableSkillCheck = true;
						SpellHelper.AddStatBonus( Caster, targ, StatType.Dex );
						SpellHelper.AddStatBonus( Caster, targ, StatType.Int ); SpellHelper.DisableSkillCheck = false;
						
						targ.FixedParticles( 0x373A, 10, 15, 5018, EffectLayer.Waist );
						targ.PlaySound( 0x1EA );
					}
					
				}
			}
			
			FinishSequence();
		}
		
		private class InternalTarget : Target
		{
			private MassMightSpell m_Owner;
			
			public InternalTarget( MassMightSpell owner ) : base( 12, true, TargetFlags.None )
			{
				m_Owner = owner;
			}
			
			protected override void OnTarget( Mobile from, object o )
			{
				IPoint3D p = o as IPoint3D;
				
				if ( p != null )
					m_Owner.Target( p );
			}
			
			protected override void OnTargetFinish( Mobile from )
			{
				m_Owner.FinishSequence();
			}
		}
	}
}
